import QtQuick 2.0
import SddmComponents 2.0

Rectangle {
    id: container
    width: 420
    height: 420

    LayoutMirroring.enabled: Qt.locale().textDirection == Qt.RightToLeft
    LayoutMirroring.childrenInherit: true

    TextConstants { id: textConstants }

    Connections {
        target: sddm

        onLoginSucceeded: {
            errorMessage.color = "#5f5f5f"
            errorMessage.text = textConstants.loginSucceeded
        }

        onLoginFailed: {
            errorMessage.color = "red"
            errorMessage.text = textConstants.loginFailed
        }
    }

    Background {
        anchors.fill: parent
        source: config.background
        fillMode: Image.PreserveAspectCrop
        onStatusChanged: {
            if (status == Image.Error && source != config.defaultBackground) {
                source = config.defaultBackground
            }
        }
    }

    Rectangle {
        anchors.fill: parent
        color: "transparent"
        //visible: primaryScreen

        Image {
            id: rectangle
            anchors.centerIn: parent
            width: 420
            height: 420

            source: "rectangle.png"

            Column {
                x: 30
                id: mainColumn
                anchors.centerIn: parent
                spacing: 20
                
                Image {
                    id: logo
                    source: "logo.png"
                    x: 140
                }

                Column {
                    width: parent.width
                    spacing: 4
                    Text {
                        color: "#FAFAFA"
                        id: lblName
                        width: parent.width
                        text: textConstants.userName
                        font.family: "Noto Sans"
                        font.pointSize: 10
                        font.weight: Font.Bold
                    }

                    TextBox {
                        id: name
                        width: parent.width; height: 30
                        text: userModel.lastUser
                        font.pixelSize: 14
                        radius: 2
                        color: "#BDBDBD"
                        borderColor: "#BDBDBD"

                        KeyNavigation.backtab: rebootButton; KeyNavigation.tab: password

                        Keys.onPressed: {
                            if (event.key === Qt.Key_Return || event.key === Qt.Key_Enter) {
                                sddm.login(name.text, password.text, session.index)
                                event.accepted = true
                            }
                        }
                    }
                }

                Column {
                    width: parent.width
                    spacing : 4
                    Text {
                        color: "#FAFAFA"
                        id: lblPassword
                        width: parent.width
                        text: textConstants.password
                        font.family: "Noto Sans"
                        font.pointSize: 10
                        font.weight: Font.Bold
                    }

                    PasswordBox {
                        id: password
                        width: parent.width; height: 30
                        font.pixelSize: 14
                        radius: 2
                        color: "#BDBDBD"
                        borderColor: "#BDBDBD"
                        
                        focus: true
                        Timer {
                            interval: 200
                            running: true
                            onTriggered: password.forceActiveFocus()
                        }

                        KeyNavigation.backtab: name; KeyNavigation.tab: session

                        Keys.onPressed: {
                            if (event.key === Qt.Key_Return || event.key === Qt.Key_Enter) {
                                sddm.login(name.text, password.text, session.index)
                                event.accepted = true
                            }
                        }
                    }
                }

                Row {
                    spacing: 4
                    width: parent.width / 2
                    z: 100

                    Column {
                        z: 100
                        width: parent.width * 1.3
                        spacing : 4
                        anchors.bottom: parent.bottom

                        Text {
                            color: "#FAFAFA"
                            id: lblSession
                            width: parent.width
                            text: textConstants.session
                            wrapMode: TextEdit.WordWrap
                            font.bold: true
                            font.pixelSize: 12
                        }

                        ComboBox {
                            id: session
                            color: "#FAFAFA"
                            borderColor: "#FAFAFA"
                            width: parent.width; height: 30
                            font.pixelSize: 14

                            arrowIcon: "angle-down.svg"

                            model: sessionModel
                            index: sessionModel.lastIndex
                            
                            font.family: "Noto Sans"
                            font.pointSize: 10
                            font.weight: Font.ExtraLight

                            KeyNavigation.backtab: password; KeyNavigation.tab: layoutBox
                        }
                    }

                    Column {
                        z: 101
                        width: parent.width * 0.7
                        spacing : 4
                        anchors.bottom: parent.bottom

                        Text {
                            color: "#FAFAFA"
                            id: lblLayout
                            width: parent.width
                            text: textConstants.layout
                            wrapMode: TextEdit.WordWrap
                            font.bold: true
                            font.pixelSize: 12
                        }

                        LayoutBox {
                            id: layoutBox
                            color: "#FAFAFA"
                            borderColor: "#FAFAFA"
                            width: parent.width; height: 30
                            font.pixelSize: 14

                            arrowIcon: "angle-down.svg"

                            KeyNavigation.backtab: session; KeyNavigation.tab: loginButton
                        }
                    }
                }

                Row {
                    spacing: 4
                    anchors.horizontalCenter: parent.horizontalCenter
                    property int btnWidth: Math.max(loginButton.implicitWidth,
                                                    shutdownButton.implicitWidth,
                                                    rebootButton.implicitWidth, 100) + 15
                    ImageButton {
                    id: loginButton
                    y:20
                    width: parent.btnWidth
                    source: "preferences-system-login.png"

                    onClicked: sddm.login(name.text, password.text, session.index)

                    KeyNavigation.backtab: layoutBox; KeyNavigation.tab: shutdownButton
                    }
                    
                    ImageButton {
                    id: rebootButton
                    y:20
                    width: parent.btnWidth
                    source: "system-reboot.png"

                    onClicked: sddm.reboot()

                    KeyNavigation.backtab: shutdownButton; KeyNavigation.tab: name
                    }
                    
                    ImageButton {
                    id: shutdownButton
                    y:20
                    width: parent.btnWidth
                    source: "system-shutdown.png"

                    onClicked: sddm.powerOff()

                    KeyNavigation.backtab: loginButton; KeyNavigation.tab: rebootButton
                    }
                }
            }
        }
    }
    
    Component.onCompleted: {
        if (name.text == "")
            name.focus = true
        else
            password.focus = true
    }
}
